@@ -3,7 +3,7 @@ use ross_protocol::packet::Packet;
 use crate::extractor::{Extractor, Value};
 
 #[repr(C)]
-#[cfg_attr(feature = "std", derive(serde::Serialize, serde::Deserialize))]
+#[derive(Debug)]
 pub struct NoneExtractor {}
 
 impl NoneExtractor {
@@ -12,7 +12,6 @@ impl NoneExtractor {
     }
 }
 
-#[cfg_attr(feature = "std", typetag::serde(name = "none_extractor"))]
 impl Extractor for NoneExtractor {
     fn extract(&self, _packet: &Packet) -> Value {
         Value::None
