@@ -3,7 +3,7 @@ use crate::state::StateManager;
 use crate::Value;
 
 #[repr(C)]
-#[cfg_attr(feature = "std", derive(serde::Serialize, serde::Deserialize))]
+#[derive(Debug)]
 pub struct U16IsEqualFilter {
     value: u16,
 }
@@ -14,7 +14,6 @@ impl U16IsEqualFilter {
     }
 }
 
-#[cfg_attr(feature = "std", typetag::serde(name = "u16_is_equal_filter"))]
 impl Filter for U16IsEqualFilter {
     fn filter(&mut self, value: &Value, _state_manager: &mut StateManager) -> bool {
         let value = match value {
